;;;
;;;alpha-org-testcase.el
;;;
;;;minimal testcase for org
;;;
;;;how to use:
;;;
;;;1) put this file in your shell's current directory.
;;;2) put any testcase org files in your shell's current directory.
;;;3) comment out the set-frame-font line if it doesn't default
;;;   nicely for you
;;;4) call like this. 
;;;
;;;   delorgsrc=your-org-src-dir emacs22 -Q -l alpha-org-testcase.el
;;;

;;;
;;;for my use i do this:
;;;
"
mep=t emacs22 -Q -l $del/tests-and-publish/alpha-org-testcase.el \
  --geometry +0+0 \
  --geometry 60x15 \
  $dorg/tests--org/export-corruption.org
"
;;;

(require 'cl)

;;my org files use these
(setq org-odd-levels-only t)
(setf org-export-initial-scope 'subtree)

;;fix abominations
(blink-cursor-mode 0)
(setf visible-bell 'top-bottom)
(defvar alpha-mac-font
  "-apple-courier-medium-r-normal--24-240-72-72-m-240-iso10646-1")
;;;'(progn
;;;  (progn
;;;    (defconst alpha-mac-font-2
;;;      "-apple-courier-medium-r-normal--*-*-*-*-*-240-*")
;;;    (set-frame-font alpha-mac-font-2))
;;;  )
(set-frame-font alpha-mac-font)

;;;   (setq mac-pass-control-to-system nil)
;;;   (setq mac-command-modifier 'hyper)
;;;   (setq mac-option-modifier 'meta)

;;basics
(defun alpha-add-path (p) (setq load-path (cons p load-path)))
(alpha-add-path (concat (getenv "delorgsrc") "/lisp"))
(add-to-list 'auto-mode-alist '("\\.org$" . org-mode))
(require 'org-install)

;;;
;;;stuff make things easier
;;;

(setq org-completion-use-ido t)
(setf org-outline-path-complete-in-steps nil)

;;;
;;;compatibility fixes
;;;

;;fix compatibility bug in org [2011-05-25 Wed 08:59]
(when (= emacs-major-version 22)
  (defun activate-mark ()
    "Activate the mark."
    (when (mark t)
      (setq mark-active t)
      (unless transient-mark-mode
        (setq transient-mark-mode 'lambda))
      (when (and select-active-regions
                 (display-selections-p))
        (x-set-selection 'PRIMARY (current-buffer))))))

;;[2011-05-25 Wed 09:23] fix compatibility bug in Org.
;;this is redefinition.  it is for 22 for export.
(defcustom select-active-regions nil
 "If non-nil, an active region automatically becomes the window selection."
 :type 'boolean
 :group 'killing
 :version "23.1")

;;;
;;;accessibility fixes
;;;
;;;you have to enable these to get them to work
;;;

(defun p ()
  (interactive)
  (message "fixing pop-up-windows")
  ;;i have /pop-up-windows/ set to nil, which works for most of
  ;;emacs.  for org, i do the following.  i need all of this just
  ;;as i need the large font above for accessibility reasons.
  ;;
  ;;(setf (cdr (assoc* 'file org-link-frame-setup)) 'find-file)
  (pushnew '(file . find-file) org-link-frame-setup :test #'equal)
  ;;it might be nice to have a 'dedicated-buffer option
  (setf org-indirect-buffer-display 'current-window)
  ;;could make pop kill the buffer
;;;(setf org-display-internal-link-with-indirect-buffer t)
  (setf org-src-window-setup 'current-window)
  (add-hook 'org-capture-mode-hook 'delete-other-windows)
  (defadvice org-agenda-set-tags (around fix-windows activate compile)
    "Restore windows."
    (save-window-excursion
      ad-do-it))
  (defadvice org-export (after fix-windows activate compile)
    "Delete other windows after every export."
    (delete-other-windows))

  (setf pop-up-windows nil)

  ;;for emacs i do this
  
  (add-to-list 'same-window-regexps "\\*Customize.*") ;notwork?
  (setf Man-notify-method 'pushy)
  (add-to-list 'same-window-regexps "\\*Man .*") ;notwork
  (add-to-list 'same-window-regexps "\\*.*\\*")
  (add-to-list 'same-window-buffer-names "*Remember*")
  (add-to-list 'same-window-buffer-names "*Help*")
  (add-to-list 'same-window-buffer-names "*Apropos*")
  (add-to-list 'same-window-buffer-names "*Summary*")
  (add-to-list 'same-window-buffer-names "*Compile-Log*")
  (add-to-list 'same-window-buffer-names "*Ibuffer*")
  (add-to-list 'same-window-buffer-names " *Ibuffer*")
  (message "done fixing pop-up-windows"))
(when (getenv "mep") (require 'org) (p))

;;;
;;;basic org features likely to affect many bug reports
;;;

(setq org-todo-keywords
      '((type  "NAKA(i)" "TODO(T)" "MAYBE(y)" "DOUBTFUL(l)"
         "|"
         "MOOT(m)")))

;;does this need loading after org-exp?
(setf org-export-initial-scope 'subtree)

(setq org-export-email-info nil)
(setq org-export-author-info nil)
(setq org-export-creator-info nil)
(setq org-export-html-preamble nil)
(setq org-export-html-postamble nil)

;;;
;;;bug-related stuff
;;;

(setf org-export-with-tasks nil)
